@@ -48,7 +48,7 @@ const BENCH_PARSEVAL_STRS: [&str; N] = [
     "2.0*3.0^2",
     "sin(-(sin(2.0)))*2.0",
     "-1*(1.3+(-0.7)*(2.0-1.0/10.0))",
-    "log(log2(2.0))*tan(2.0)+exp(1.5)",
+    "ln(log2(2.0))*tan(2.0)+exp(1.5)",
 ];
 
 const BENCH_PARSEVAL_REFS: [f64; N] = [18.0, -1.5781446871457767, 0.03, 4.4816890703380645];
