@@ -282,11 +282,16 @@ pub trait MakeOperators<T: Clone>: Clone {
 /// |`exp`| exponential functionn |
 /// |`sqrt`| square root |
 /// |`cbrt`| cube root |
-/// |`log`| natural logarithm  |
-/// |`log2`| logarithm with basis 2  |
-/// |`PI`| constant π  |
-/// |`π`| second representations of constant π  |
+/// |`ln`| natural logarithm |
+/// |`log2`| logarithm with basis 2 |
+/// |`log10`| logarithm with basis 10 |
+/// |`log`| natural logarithm |
+/// |`PI`| constant π |
+/// |`π`| second representation of constant π |
+/// |`TAU`| constant τ=2π |
+/// |`τ`| second representation of constant τ |
 /// |`E`| Euler's number |
+/// |`e`| second representation of Euler's number |
 ///
 ///
 #[derive(Clone, Eq, PartialEq, Ord, PartialOrd, Debug)]
@@ -359,11 +364,14 @@ impl<T: Float> MakeOperators<T> for FloatOpsFactory<T> {
             Operator::make_unary("exp", |a| a.exp()),
             Operator::make_unary("sqrt", |a| a.sqrt()),
             Operator::make_unary("cbrt", |a| a.cbrt()),
-            Operator::make_unary("log", |a| a.ln()),
+            Operator::make_unary("ln", |a| a.ln()),
             Operator::make_unary("log2", |a| a.log2()),
+            Operator::make_unary("log10", |a| a.log10()),
+            Operator::make_unary("log", |a| a.ln()),
             Operator::make_constant("PI", T::from(std::f64::consts::PI).unwrap()),
             Operator::make_constant("π", T::from(std::f64::consts::PI).unwrap()),
             Operator::make_constant("E", T::from(std::f64::consts::E).unwrap()),
+            Operator::make_constant("e", T::from(std::f64::consts::E).unwrap()),
             Operator::make_constant("TAU", T::from(std::f64::consts::TAU).unwrap()),
             Operator::make_constant("τ", T::from(std::f64::consts::TAU).unwrap()),
             
