@@ -1,5 +1,6 @@
 use std::{
     fmt::{self, Debug, Display, Formatter},
+    iter,
     str::FromStr,
 };
 
@@ -64,14 +65,96 @@ where
     where
         T: DataType + Float,
         <T as FromStr>::Err: Debug,
+    {
+        self.partial_nth(var_idx, 1)
+    }
+
+    /// *`feature = "partial"`* - Computes the nth partial derivative with respect to one variable
+    /// # Example
+    /// ```rust
+    /// # use std::error::Error;
+    /// # fn main() -> Result<(), Box<dyn Error>> {
+    /// #
+    /// use exmex::prelude::*;
+    ///
+    /// let mut expr = FlatEx::<f64>::from_str("x^4+y^4")?;
+    ///
+    /// let dexpr_dxx_nth = expr.partial_nth(0, 2)?;
+    ///
+    /// let dexpr_dx = expr.partial(0)?;
+    /// let dexpr_dxx_2step = dexpr_dx.partial(0)?;
+    ///
+    /// assert!((dexpr_dxx_2step.eval(&[4.3, 2.1])? - dexpr_dxx_nth.eval(&[4.3, 2.1])?).abs() < 1e-12);
+    /// #
+    /// #     Ok(())
+    /// # }
+    /// ```
+    /// # Arguments
+    ///
+    /// * `var_idx` - variable with respect to which the partial derivative is computed
+    /// * `n` - order of derivation
+    ///
+    /// # Errors
+    ///
+    /// * If you use custom operators this might not work as expected. It could return an [`ExError`](crate::ExError) if
+    ///   an operator is not found or compute a wrong result if an operator is defined in an un-expected way.
+    ///
+    fn partial_nth(&self, var_idx: usize, n: usize) -> ExResult<Self>
+    where
+        T: DataType + Float,
+        <T as FromStr>::Err: Debug,
+    {
+        self.partial_iter(iter::repeat(&var_idx).take(n))
+    }
+
+    /// *`feature = "partial"`* - Computes a chain of partial derivatives with respect to the variables passed as iterator
+    ///
+    /// # Example
+    /// ```rust
+    /// # use std::error::Error;
+    /// # fn main() -> Result<(), Box<dyn Error>> {
+    /// #
+    /// use exmex::prelude::*;
+    ///
+    /// let mut expr = FlatEx::<f64>::from_str("x^4+y^4")?;
+    ///
+    /// let dexpr_dxy_iter = expr.partial_iter([0, 1].iter())?;
+    ///
+    /// let dexpr_dx = expr.partial(0)?;
+    /// let dexpr_dxy_2step = dexpr_dx.partial(1)?;
+    ///
+    /// assert!((dexpr_dxy_2step.eval(&[4.3, 2.1])? - dexpr_dxy_iter.eval(&[4.3, 2.1])?).abs() < 1e-12);
+    /// #
+    /// #     Ok(())
+    /// # }
+    /// ```
+    /// # Arguments
+    ///
+    /// * `var_idxs` - variables with respect to which the partial derivative is computed
+    /// * `n` - order of derivation
+    ///
+    /// # Errors
+    ///
+    /// * If you use custom operators this might not work as expected. It could return an [`ExError`](crate::ExError) if
+    ///   an operator is not found or compute a wrong result if an operator is defined in an un-expected way.
+    ///
+    fn partial_iter<'a, I>(&self, var_idxs: I) -> ExResult<Self>
+    where
+        T: DataType + Float,
+        <T as FromStr>::Err: Debug,
+        I: Iterator<Item = &'a usize> + Clone,
     {
         let ops = Self::OperatorFactory::make();
-        let deepex = self.to_deepex(&ops)?;
+        let mut deepex = self.to_deepex(&ops)?;
 
         let unparsed = deepex.unparse();
-        details::check_partial_index(var_idx, self.var_names().len(), unparsed.as_str())?;
-        let d_i = partial_deepex(var_idx, deepex, &ops)?;
-        Self::from_deepex(d_i, &ops)
+        for var_idx in var_idxs.clone() {
+            details::check_partial_index(*var_idx, self.var_names().len(), unparsed.as_str())?;
+        }
+        for var_idx in var_idxs {
+            deepex = partial_deepex(*var_idx, deepex, &ops)?;
+        }
+        Self::from_deepex(deepex, &ops)
     }
 
     /// *`feature = "partial"`* - Every trait implementation needs to implement the conversion to a deep
@@ -716,6 +799,28 @@ fn minus_find_unary<'a, T: Copy + Debug>(
     find_as_unary_op_with_reprs("-", ops)
 }
 
+enum Base {
+    Two,
+    Ten,
+    Euler,
+}
+fn log_deri<'a, T: Float + Debug>(
+    f: DeepEx<'a, T>,
+    base: Base,
+    ops: &[Operator<'a, T>],
+) -> ExResult<DeepEx<'a, T>> {
+    let div_op = div_find(ops)?;
+    let lazy_mul_op = || mul_find(ops);
+    let ln_base = |base_float: f64| DeepEx::from_num(T::from(base_float).unwrap().ln());
+    let x = f.with_new_latest_unary_op(UnaryOpWithReprs::new());
+    let denominator = match base {
+        Base::Ten => mul(x, ln_base(10.0), lazy_mul_op()?)?,
+        Base::Two => mul(x, ln_base(2.0), lazy_mul_op()?)?,
+        Base::Euler => x,
+    };
+    div(DeepEx::one(), denominator, div_op)
+}
+
 pub fn make_partial_derivative_ops<'a, T: Float + Debug>() -> Vec<PartialDerivative<'a, T>> {
     vec![
         PartialDerivative {
@@ -726,7 +831,7 @@ pub fn make_partial_derivative_ops<'a, T: Float + Debug>() -> Vec<PartialDerivat
                  ops: &[Operator<'a, T>]|
                  -> ExResult<ValueDerivative<T>> {
                     let pow_op = pow_find(ops)?;
-                    let log_op = find_as_unary_op_with_reprs("log", ops)?;
+                    let ln_op = find_as_unary_op_with_reprs("ln", ops)?;
                     let mul_op = mul_find(ops)?;
                     let add_op = add_find(ops)?;
                     let sub_op = sub_find(ops)?;
@@ -745,7 +850,7 @@ pub fn make_partial_derivative_ops<'a, T: Float + Debug>() -> Vec<PartialDerivat
                     )?;
 
                     let der_2 = mul(
-                        mul(val.clone(), f.val.operate_unary(log_op), mul_op.clone())?,
+                        mul(val.clone(), f.val.operate_unary(ln_op), mul_op.clone())?,
                         g.der.clone(),
                         mul_op,
                     )?;
@@ -858,16 +963,29 @@ pub fn make_partial_derivative_ops<'a, T: Float + Debug>() -> Vec<PartialDerivat
             ),
         },
         PartialDerivative {
-            repr: "log",
+            repr: "ln",
             bin_op: None,
             unary_outer_op: Some(
                 |f: DeepEx<'a, T>, ops: &[Operator<'a, T>]| -> ExResult<DeepEx<'a, T>> {
-                    let div_op = div_find(ops)?;
-                    div(
-                        DeepEx::one(),
-                        f.with_new_latest_unary_op(UnaryOpWithReprs::new()),
-                        div_op,
-                    )
+                    log_deri(f, Base::Euler, ops)
+                },
+            ),
+        },
+        PartialDerivative {
+            repr: "log10",
+            bin_op: None,
+            unary_outer_op: Some(
+                |f: DeepEx<'a, T>, ops: &[Operator<'a, T>]| -> ExResult<DeepEx<'a, T>> {
+                    log_deri(f, Base::Ten, ops)
+                },
+            ),
+        },
+        PartialDerivative {
+            repr: "log2",
+            bin_op: None,
+            unary_outer_op: Some(
+                |f: DeepEx<'a, T>, ops: &[Operator<'a, T>]| -> ExResult<DeepEx<'a, T>> {
+                    log_deri(f, Base::Two, ops)
                 },
             ),
         },
